/*********************************************************************
 *
 *                Microchip USB C18 Firmware - Mouse Demo
 *
 *********************************************************************
 * FileName:        user_mouse.c
 * Dependencies:    See INCLUDES section below
 * Processor:       PIC18
 * Compiler:        C18 2.30.01+
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * The software supplied herewith by Microchip Technology Incorporated
 * (the CompanyE for its PICmicro Microcontroller is intended and
 * supplied to you, the Companys customer, for use solely and
 * exclusively on Microchip PICmicro Microcontroller products. The
 * software is owned by the Company and/or its supplier, and is
 * protected under applicable copyright laws. All rights are reserved.
 * Any use in violation of the foregoing restrictions may subject the
 * user to criminal sanctions under applicable laws, as well as to
 * civil liability for the breach of the terms and conditions of this
 * license.
 *
 * THIS SOFTWARE IS PROVIDED IN AN AS ISECONDITION. NO WARRANTIES,
 * WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 * IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Rawin Rojvanit       11/19/04    Original.
 ********************************************************************/

/** I N C L U D E S **********************************************************/
#include <p18cxxx.h>
#include "system\typedefs.h"

#include "system\usb\usb.h"

#include "io_cfg.h"             // I/O pin mapping
#include "user.h"
#include "delays.h"

/** V A R I A B L E S ********************************************************/
#pragma udata
char Buffer[64];

/** P R I V A T E  P R O T O T Y P E S ***************************************/
void setdefaultacd(void);
void getacd(int port, int config);

/** D E C L A R A T I O N S **************************************************/
#pragma code
void UserInit(void)
{
	TRISC = 252;
	PORTC = 0;
}//end UserInit



void setdefaultacd(void)
{
		/* 12 TAD FOSC/32 */
		ADCON2=42;
		/* AN0-15, VREF */
		ADCON1 = 0b00001011;
		/* Turn on the ADC */
		ADCON0bits.ADON = 1;
		ADCON0bits.CHS3 = 0;
		ADCON0bits.CHS2 = 0;
}

void getacd(int port, int config)
{
	if (config) setdefaultacd();
// FOSC/32 clock select
	switch (port) {
		case 0 : {ADCON0bits.CHS1=0;ADCON0bits.CHS0=0;}   break;
		case 1 : {ADCON0bits.CHS1=0;ADCON0bits.CHS0=1;}   break;
		case 2 : {ADCON0bits.CHS1=1;ADCON0bits.CHS0=0;}   break;
		case 3 : {ADCON0bits.CHS1=1;ADCON0bits.CHS0=1;}   break;
	}
	ADCON0bits.GO = 1;
	while (ADCON0bits.GO);
}


/******************************************************************************
 * Function:        void ProcessIO(void)
 *
 * PreCondition:    None
 *
 * Input:           None
 *
 * Output:          None
 *
 * Side Effects:    None
 *
 * Overview:        This function is a place holder for other user routines.
 *                  It is a mixture of both USB and non-USB tasks.
 *
 * Note:            None
 *****************************************************************************/
void ProcessIO(void)
{   
	int i;
	static pressed=0;


   if (HIDRxReport(Buffer,PacketSize ) > 0) // USB receive buffer has data
    {	
		PORTCbits.RC0 = 1;


		if (Buffer[0]==1){
			for (i=0; i<Buffer[1]; i++) {
				PORTCbits.RC1 = 1;
				Delay10KTCYx(Buffer[2]);
				PORTCbits.RC1 = 0;	
				Delay10KTCYx(Buffer[2]);
				}
			}	

		if (Buffer[0]==0)
			{
			Buffer[0]=255;
			getacd(0, 1);
			Buffer[1] = ADRESH ;
			Buffer[2] = ADRESL ;
			}			
		
		

        if(!mHIDTxIsBusy()) {                 // blocking
        HIDTxReport(Buffer, PacketSize ); }  // transmit packet

		PORTCbits.RC0 = 0;
	}

	if (PORTCbits.RC2 == 0) {
		if (!pressed) {

			Buffer[0]=255;
			getacd(0, 1);
			Buffer[1] = ADRESH ;
			Buffer[2] = ADRESL ;
			 if(!mHIDTxIsBusy()) {                // blocking
        		HIDTxReport(Buffer, PacketSize );   // transmit packet
				pressed=1;
			}
		}
	}

	if (PORTCbits.RC2 == 1) {
		pressed=0;
	}




}//end ProcessIO



/** EOF user_mouse.c *********************************************************/
